@@ -1,5 +1,5 @@
 package Net::Cisco::FMC::v1;
-$Net::Cisco::FMC::v1::VERSION = '0.002001';
+$Net::Cisco::FMC::v1::VERSION = '0.003001';
 # ABSTRACT: Cisco Firepower Management Center (FMC) API version 1 client library
 
 use 5.024;
@@ -33,8 +33,9 @@ has '_refresh_token' => (
 
 with 'Net::Cisco::FMC::v1::Role::REST::Client';
 
-sub _create ($self, $url, $object_data) {
-    my $res = $self->post($url, $object_data);
+sub _create ($self, $url, $object_data, $query_params = {}) {
+    my $params = $self->user_agent->www_form_urlencode( $query_params );
+    my $res = $self->post("$url?$params", $object_data);
     my $code = $res->code;
     my $data = $res->data;
     croak($data->{error}->{messages}[0]->{description})
@@ -229,7 +230,7 @@ sub relogin($self) {
 }
 
 
-sub create_accessrule ($self, $accesspolicy_id, $object_data) {
+sub create_accessrule ($self, $accesspolicy_id, $object_data, $query_params = {}) {
     return $self->_create(join('/',
             '/api/fmc_config/v1/domain',
             $self->domain_uuid,
@@ -237,7 +238,7 @@ sub create_accessrule ($self, $accesspolicy_id, $object_data) {
             'accesspolicies',
             $accesspolicy_id,
             'accessrules'
-        ), $object_data);
+        ), $object_data, $query_params);
 }
 
 
@@ -597,7 +598,7 @@ Net::Cisco::FMC::v1 - Cisco Firepower Management Center (FMC) API version 1 clie
 
 =head1 VERSION
 
-version 0.002001
+version 0.003001
 
 =head1 SYNOPSIS
 
@@ -626,14 +627,13 @@ version 0.002001
 This module is a client library for the Cisco Firepower Management
 Center (FMC) REST API version 1.
 Currently it is developed and tested against FMC version 6.2.3.6.
-Older FMC versions have bugs like:
 
 =head1 ATTRIBUTES
 
 =head2 domains
 
 Returns a list of hashrefs containing name and uuid of all domains which gets
-populated by L<login>.
+populated by L</login>.
 
 =head2 domain_uuid
 
@@ -653,7 +653,8 @@ restores the currently set domain_uuid.
 
 =head2 create_accessrule
 
-Takes an access policy id and a hashref of the rule which should be created.
+Takes an access policy id, a hashref of the rule which should be created and
+optional query parameters.
 
 =head2 list_accessrules
 
@@ -750,6 +751,8 @@ Supports resuming.
 
 =head1 KNOWN BUGS
 
+Older FMC versions have bugs like:
+
 =over
 
 =item truncated JSON responses
@@ -774,7 +777,7 @@ Alexander Hartmaier <abraxxa@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Alexander Hartmaier.
+This software is copyright (c) 2018 - 2019 by Alexander Hartmaier.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
