@@ -1,5 +1,5 @@
 package Net::Cisco::FMC::v1::Role::ObjectMethods;
-$Net::Cisco::FMC::v1::Role::ObjectMethods::VERSION = '0.002001';
+$Net::Cisco::FMC::v1::Role::ObjectMethods::VERSION = '0.003001';
 # ABSTRACT: Role for Cisco Firepower Management Center (FMC) API version 1 method generation
 
 use 5.024;
@@ -78,9 +78,17 @@ role {
         for my $object ($self->$listname({ expanded => 'true' })->{items}->@*) {
             my $identical = 1;
             for my $key (keys $query_params->%*) {
-                if ($object->{$key} ne $query_params->{$key}) {
-                    $identical = 0;
-                    last;
+                if ( ref $query_params->{$key} eq 'Regexp') {
+                    if ($object->{$key} !~ $query_params->{$key}) {
+                        $identical = 0;
+                        last;
+                    }
+                }
+                else {
+                    if ($object->{$key} ne $query_params->{$key}) {
+                        $identical = 0;
+                        last;
+                    }
                 }
             }
             if ($identical) {
@@ -105,7 +113,7 @@ Net::Cisco::FMC::v1::Role::ObjectMethods - Role for Cisco Firepower Management C
 
 =head1 VERSION
 
-version 0.002001
+version 0.003001
 
 =head1 SYNOPSIS
 
@@ -196,7 +204,7 @@ Alexander Hartmaier <abraxxa@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Alexander Hartmaier.
+This software is copyright (c) 2018 - 2019 by Alexander Hartmaier.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
